@@ -1,3 +1,4 @@
+import logging
 import time
 
 from openshift.dynamic.exceptions import ConflictError
@@ -6,6 +7,8 @@ from ocp_resources.resource import Resource
 from ocp_resources.utils import TimeoutSampler
 
 
+LOGGER = logging.getLogger(__name__)
+
 SLEEP = 1
 TIMEOUT = 240
 
@@ -13,20 +16,20 @@ TIMEOUT = 240
 class NodeNetworkState(Resource):
     api_group = Resource.ApiGroup.NMSTATE_IO
 
-    def __init__(self, name, client=None, teardown=True):
-        super().__init__(name=name, client=client, teardown=teardown)
+    def __init__(self, name=None, client=None, teardown=True, yaml_file=None):
+        super().__init__(
+            name=name, client=client, teardown=teardown, yaml_file=yaml_file
+        )
         status = self.instance.to_dict()["status"]
-        if "desiredState" in status:
-            self.desired_state = status["desiredState"]
-        else:
-            self.desired_state = {"interfaces": []}
+        self.desired_state = status.get("desiredState", {"interfaces": []})
 
     def set_interface(self, interface):
+
         # First drop the interface is's already in the list
         interfaces = [
-            i
-            for i in self.desired_state["interfaces"]
-            if not (i["name"] == interface["name"])
+            iface
+            for iface in self.desired_state["interfaces"]
+            if iface["name"] != interface["name"]
         ]
 
         # Add the interface
@@ -35,6 +38,9 @@ class NodeNetworkState(Resource):
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         res.update(
             {
                 "spec": {
@@ -68,7 +74,7 @@ class NodeNetworkState(Resource):
 
             return None
 
-        self.logger.info(f"Checking if interface {name} is up -- {self.name}")
+        LOGGER.info(f"Checking if interface {name} is up -- {self.name}")
         samples = TimeoutSampler(
             wait_timeout=TIMEOUT, sleep=SLEEP, func=_find_up_interface
         )
@@ -77,7 +83,7 @@ class NodeNetworkState(Resource):
                 return
 
     def wait_until_deleted(self, name):
-        self.logger.info(f"Checking if interface {name} is deleted -- {self.name}")
+        LOGGER.info(f"Checking if interface {name} is deleted -- {self.name}")
         samples = TimeoutSampler(
             wait_timeout=TIMEOUT, sleep=SLEEP, func=self.get_interface, name=name
         )
